==> 1.0.0.tar.gz: ionisx/app/controllers/home.controller.js <==
angular.module('app')
    .controller('HomeController', ['$scope', '$state',
        function($scope, $state) {

            $scope.Data = {
                Input: "",
                Output: ""
            };

            $scope.questions = [];

            $scope.macros = [];

            $scope.addMacro = function(latex, html)
            {
                $scope.macros.push({
                    latex: latex,
                    html: html
                });
            };

            $scope.formatText = function(text)
            {
                text = text.replace(/\$([^\$]+)\$/g, function($1, $2)
                {
                    return "\\(" + $2 + "\\)";
                }).replace(/\\medskip/, "")
                    .replace(/\\begin\{.*\}/g, "")
                    .replace(/\\end\{.*\}/g, "")
                    .replace(/\n|\r|\r\n|\n\r/g, " ")
                    .replace(/ +/, " ")
                    .trim();
                $scope.macros.forEach(function(macro)
                {
                    text = text.replace(macro.latex, macro.html);
                });
                return text;
            };

            $scope.convert = function()
            {
                $scope.Data.Output = "";
                $scope.questions = [];
                var input = $scope.Data.Input;
                $scope.Data.Output = "";

                var questions = input.split("\\section");
                questions.splice(0, 1);

                var firstQuestion = null;
                questions.forEach(function(questionStr)
                {
                    var question = {
                        Text: "",
                        Answers: []
                    };
                    var responses = questionStr.split("\\item");
                    question.Text = responses[0].replace(/^\*\{.* ([0-9]+).*\}/, function($1, $2)
                    {
                        $2 = parseInt($2);
                        if (firstQuestion == null) {
                            firstQuestion = $2;
                        }
                        return "Question " + ($2 - firstQuestion + 1) + "\n";
                    });
                    question.Text = $scope.formatText(question.Text);
                    responses.splice(0, 1);

                    responses.forEach(function(answerStr) {
                        answerStr = answerStr.replace(/\\medskip/, "").trim();
                        var a = answerStr.match(/^\[[^\]\[]+\]/)[0];
                        answerStr = answerStr.substring(a.length, answerStr.length);
                        answerStr = $scope.formatText(answerStr);
                        question.Answers.push({
                            Text: answerStr,
                            Correct: a.length != 4
                        })
                    });

                    $scope.questions.push(question);
                });

                $scope.questions.forEach(function(question)
                {
                    $scope.Data.Output += question.Text + "\n";

                    var goodAnswersCount = 0;
                    question.Answers.forEach(function(answer)
                    {
                        if (answer.Correct) {
                            ++goodAnswersCount;
                        }
                    });

                    question.Answers.forEach(function(answer)
                    {
                        $scope.Data.Output += "\t" + (goodAnswersCount > 1 ? "[" : "(") + (answer.Correct ? "x" : "") +
                            (goodAnswersCount > 1 ? "]" : ")") + answer.Text + "\n";
                    });
                    $scope.Data.Output += "\n";
                });
            };

            $scope.addMacro("\\RR", "\\mathbb{R}");
            $scope.addMacro("\\CC", "\\mathbb{C}");
            $scope.addMacro("\\QQ", "\\mathbb{Q}");
            $scope.addMacro("\\di", "\\displaystyle");
            $scope.addMacro("\\dd", "\\text{d}");
            $scope.addMacro("<<", "&#171");
            $scope.addMacro(">>", "&#187");
            $scope.addMacro("<", "&#60");
            $scope.addMacro(">", "&#62");
            $scope.addMacro("\\\'{E}", "&#201");
            $scope.addMacro("\\\'{A}", "&#192");
    }]);

==> 1.0.5.tar.gz: ionisx/app/controllers/home.controller.js <==
angular.module('app')
    .controller('HomeController', ['$scope', '$state',
        function($scope, $state) {

            $scope.Data = {
                Input: "",
                Output: ""
            };

            $scope.questions = [];

            $scope.macros = [];

            $scope.escapeRegExp = function(str)
            {
                return str.replace(/[\-\[\]\/\{\}\(\)\*\+\?\.\\\^\$\|]/g, "\\$&");
            };

            $scope.addMacro = function(latex, html)
            {
                $scope.macros.push({
                    latex: latex,
                    html: html
                });
            };

            $scope.formatText = function(text)
            {
                text = text.replace(/\$([^\$]+)\$/g, function($1, $2)
                {
                    return "\\(" + $2 + "\\)";
                }).replace(/\\medskip/g, "")
                    .replace(/\\begin\{.*\}/g, "")
                    .replace(/\\end\{.*\}/g, "")
                    .replace(/\n|\r|\r\n|\n\r/g, " ")
                    .replace(/ +/g, " ")
                    .trim();
                $scope.macros.forEach(function(macro)
                {
                    var regex = macro.latex.match(/[a-zA-Z0-9]$/) != null ? "([^a-zA-Z0-9])" : "()";
                    text = text.replace(new RegExp($scope.escapeRegExp(macro.latex) + regex, "g"), function($1, $2)
                    {
                        return macro.html + $2;
                    });
                });
                return text;
            };

            $scope.convert = function()
            {
                $scope.Data.Output = "";
                $scope.questions = [];
                var input = $scope.Data.Input;
                $scope.Data.Output = "";

                var questions = input.split("\\section");
                questions.splice(0, 1);

                questions.forEach(function(questionStr)
                {
                    var question = {
                        Text: "",
                        Answers: []
                    };
                    var responses = questionStr.split("\\item");
                    question.Text = $scope.formatText(responses[0]);
                    question.Text = question.Text.replace(/^\*\{([^\}]*)\}/, function($1, $2)
                    {
                        return $2 + "\n";
                    });
                    responses.splice(0, 1);

                    responses.forEach(function(answerStr) {
                        answerStr = answerStr.replace(/\\medskip/, "").trim();
                        var a = answerStr.match(/^\[[^\]\[]+\]/)[0];
                        answerStr = answerStr.substring(a.length, answerStr.length);
                        answerStr = $scope.formatText(answerStr);
                        question.Answers.push({
                            Text: answerStr,
                            Correct: a.length != 4
                        })
                    });

                    $scope.questions.push(question);
                });

                $scope.questions.forEach(function(question)
                {
                    $scope.Data.Output += question.Text + "\n";



                    question.Answers.forEach(function(answer)
                    {
                        $scope.Data.Output += "\t[" + (answer.Correct ? "x" : "") + "]" + answer.Text + "\n";
                    });
                    $scope.Data.Output += "\n";
                });
            };

            $scope.setDraggedContent = function(data, file)
            {
                $scope.Data.Input = data;
                $scope.convert();
            };

            $scope.addMacro("\\RR", "\\mathbb{R}");
            $scope.addMacro("\\CC", "\\mathbb{C}");
            $scope.addMacro("\\QQ", "\\mathbb{Q}");
            $scope.addMacro("\\NN", "\\mathbb{N}");
            $scope.addMacro("\\ZZ", "\\mathbb{Z}");
            $scope.addMacro("\\di", "\\displaystyle");
            $scope.addMacro("\\dd", "\\text{d}");
            $scope.addMacro("<<", "&#171;");
            $scope.addMacro(">>", "&#187;");
            $scope.addMacro("<", "&#60; ");
            $scope.addMacro(">", "&#62;");
            $scope.addMacro("\\\'{E}", "&#201;");
            $scope.addMacro("\\`{A}", "&#192;");
    }]);
